You will need two data frames. If they are not specified as arguments, you will be prompted to import them from CSV format.
The resulting data frame from the op_calculate() function will be a data frame of species (rows) and the optima and tolerance range (+ and -) of the environmental variables (columns)
Matrix 1: Species (rows) by Sampling sites (columns).
First row needs to be the sampling sites names.
First column needs to be the species' names.
Values in cells therefore need to be the density of each species at each site.
Matrix 2: Environmental variables (rows) by Sampling sites (columns).
First row needs to be the sampling sites names.
First column needs to be the names of the environmental variables (i.e. physical-chemical parameters).
Values in cells therefore need to be the value of each environmental variable at each site.
The calculations for optima and tolerance ranges is conducted according to the article by Potapova & Charles (2003):
Potapova, M., & Charles, D. F. (2003). Distribution of benthic diatoms in US rivers in relation to conductivity and ionic composition. Freshwater Biology, 48(8), 1311-1328.
Sample data is taken from: